import { I18NConfig, PartialAll, I18NFormat } from './types';
export * from './types';
export declare const defaultFormats: {
    date: {
        default: {
            year: string;
            month: string;
            day: string;
        };
        shortYear: {
            year: string;
        };
        year: {
            year: string;
        };
        shortYearMonth: {
            year: string;
            month: string;
        };
        yearMonth: {
            year: string;
            month: string;
        };
        shortMonthDay: {
            month: string;
            day: string;
        };
        monthDay: {
            month: string;
            day: string;
        };
        shortMonth: {
            month: string;
        };
        month: {
            month: string;
        };
        shortDay: {
            day: string;
        };
        day: {
            day: string;
        };
        short: {
            year: string;
            month: string;
            day: string;
        };
        long: {
            year: string;
            month: string;
            day: string;
        };
        full: {
            year: string;
            month: string;
            day: string;
            weekday: string;
        };
        longDateTime: {
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
        };
        shortDateTime: {
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
        };
    };
    time: {
        default: {
            hour: string;
            minute: string;
        };
        short: {
            hour: string;
            minute: string;
        };
        medium: {
            hour: string;
            minute: string;
        };
        long: {
            hour: string;
            minute: string;
            second: string;
            timeZoneName: string;
        };
        full: {
            hour: string;
            minute: string;
            second: string;
            timeZoneName: string;
        };
    };
    number: {
        default: {
            style: string;
            minimumFractionDigits: number;
        };
        int: {
            style: string;
            minimumFractionDigits: number;
        };
        currency: {
            style: string;
            minimumFractionDigits: number;
            currency: string;
        };
        precent: {
            style: string;
            minimumFractionDigits: number;
        };
        k: {
            style: string;
        };
    };
    relative: {
        default: {
            numeric: string;
            unit: string;
        };
        seconds: {
            style: string;
            unit: string;
        };
        minutes: {
            numeric: string;
            unit: string;
        };
        hours: {
            numeric: string;
            unit: string;
        };
        days: {
            numeric: string;
            unit: string;
        };
        weeks: {
            numeric: string;
            unit: string;
        };
        months: {
            numeric: string;
            unit: string;
        };
        quarters: {
            numeric: string;
            unit: string;
        };
        years: {
            numeric: string;
            unit: string;
        };
        second: {
            numeric: string;
            unit: string;
        };
        minute: {
            numeric: string;
            unit: string;
        };
        hour: {
            numeric: string;
            unit: string;
        };
        day: {
            numeric: string;
            unit: string;
        };
        week: {
            numeric: string;
            unit: string;
        };
        month: {
            numeric: string;
            unit: string;
        };
        quarter: {
            numeric: string;
            unit: string;
        };
        year: {
            numeric: string;
            unit: string;
        };
    };
    plural: {
        default: {
            type: string;
        };
        cardinal: {
            type: string;
        };
        ordinal: {
            type: string;
        };
    };
};
export declare type RelativeTimeFormatID = keyof (typeof defaultFormats.relative);
export declare const relativeFormatIDs: ("default" | "day" | "hour" | "minute" | "month" | "second" | "year" | "years" | "quarter" | "quarters" | "months" | "week" | "weeks" | "days" | "hours" | "minutes" | "seconds")[];
export declare type PluralFormatID = keyof (typeof defaultFormats.plural);
export declare const pluralFormatIDs: ("default" | "cardinal" | "ordinal")[];
export declare type NumberFormatID = keyof (typeof defaultFormats.number);
export declare const numberFormatIDs: NumberFormatID[];
export declare type DateFormatID = keyof (typeof defaultFormats.date);
export declare const dateFormatIDs: ("long" | "short" | "default" | "day" | "month" | "year" | "full" | "shortYear" | "shortYearMonth" | "yearMonth" | "shortMonthDay" | "monthDay" | "shortMonth" | "shortDay" | "longDateTime" | "shortDateTime")[];
export declare type TimeFormatID = keyof (typeof defaultFormats.time);
export declare const timeFormatIDs: ("long" | "short" | "default" | "medium" | "full")[];
export declare type FormatDateTimeValue = Parameters<Intl.DateTimeFormat['format']>[0];
export declare const defaultI18NOption: I18NConfig;
export declare const getI18NConfig: (a: I18NConfig) => (b?: PartialAll<I18NConfig>) => I18NConfig;
export declare type StandConfig<MK extends string = string> = I18NConfig<MK, DateFormatID, TimeFormatID, NumberFormatID, PluralFormatID, RelativeTimeFormatID>;
export declare type MonadI18N<MK extends string = string> = I18NFormat<MK, DateFormatID, TimeFormatID, NumberFormatID, PluralFormatID, RelativeTimeFormatID>;
export declare const extendI18NConfig: (b?: PartialAll<I18NConfig>) => I18NConfig;
export declare const buildMonadI18N: <MK extends string = string>(a?: {
    defaultLocale?: string | undefined;
    template?: {
        messages?: PartialAll<Record<MK, string>> | undefined;
        relative?: {
            default?: any;
            day?: any;
            hour?: any;
            minute?: any;
            month?: any;
            second?: any;
            year?: any;
            years?: any;
            quarter?: any;
            quarters?: any;
            months?: any;
            week?: any;
            weeks?: any;
            days?: any;
            hours?: any;
            minutes?: any;
            seconds?: any;
        } | undefined;
        plural?: {
            default?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                type?: Intl.PluralRuleType | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                locale?: string | undefined;
            } | undefined;
            cardinal?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                type?: Intl.PluralRuleType | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                locale?: string | undefined;
            } | undefined;
            ordinal?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                type?: Intl.PluralRuleType | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                locale?: string | undefined;
            } | undefined;
        } | undefined;
        number?: {
            default?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                currency?: string | undefined;
                currencySign?: "standard" | "accounting" | undefined;
                useGrouping?: boolean | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                compactDisplay?: "long" | "short" | undefined;
                notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                unitDisplay?: "long" | "short" | "narrow" | undefined;
                currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                numberingSystem?: string | undefined;
                locale?: string | undefined;
            } | undefined;
            currency?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                currency?: string | undefined;
                currencySign?: "standard" | "accounting" | undefined;
                useGrouping?: boolean | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                compactDisplay?: "long" | "short" | undefined;
                notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                unitDisplay?: "long" | "short" | "narrow" | undefined;
                currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                numberingSystem?: string | undefined;
                locale?: string | undefined;
            } | undefined;
            int?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                currency?: string | undefined;
                currencySign?: "standard" | "accounting" | undefined;
                useGrouping?: boolean | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                compactDisplay?: "long" | "short" | undefined;
                notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                unitDisplay?: "long" | "short" | "narrow" | undefined;
                currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                numberingSystem?: string | undefined;
                locale?: string | undefined;
            } | undefined;
            precent?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                currency?: string | undefined;
                currencySign?: "standard" | "accounting" | undefined;
                useGrouping?: boolean | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                compactDisplay?: "long" | "short" | undefined;
                notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                unitDisplay?: "long" | "short" | "narrow" | undefined;
                currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                numberingSystem?: string | undefined;
                locale?: string | undefined;
            } | undefined;
            k?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                currency?: string | undefined;
                currencySign?: "standard" | "accounting" | undefined;
                useGrouping?: boolean | undefined;
                minimumIntegerDigits?: number | undefined;
                minimumFractionDigits?: number | undefined;
                maximumFractionDigits?: number | undefined;
                minimumSignificantDigits?: number | undefined;
                maximumSignificantDigits?: number | undefined;
                compactDisplay?: "long" | "short" | undefined;
                notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                unitDisplay?: "long" | "short" | "narrow" | undefined;
                currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                numberingSystem?: string | undefined;
                locale?: string | undefined;
            } | undefined;
        } | undefined;
        date?: {
            long?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            short?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            default?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            day?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            month?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            year?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            full?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            shortYear?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            shortYearMonth?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            yearMonth?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            shortMonthDay?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            monthDay?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            shortMonth?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            shortDay?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            longDateTime?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            shortDateTime?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
        } | undefined;
        time?: {
            long?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            short?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            default?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            medium?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
            full?: {
                localeMatcher?: "best fit" | "lookup" | undefined;
                weekday?: "long" | "short" | "narrow" | undefined;
                era?: "long" | "short" | "narrow" | undefined;
                year?: "numeric" | "2-digit" | undefined;
                month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                day?: "numeric" | "2-digit" | undefined;
                hour?: "numeric" | "2-digit" | undefined;
                minute?: "numeric" | "2-digit" | undefined;
                second?: "numeric" | "2-digit" | undefined;
                timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                formatMatcher?: "best fit" | "basic" | undefined;
                hour12?: boolean | undefined;
                timeZone?: string | undefined;
                calendar?: string | undefined;
                dayPeriod?: "long" | "short" | "narrow" | undefined;
                numberingSystem?: string | undefined;
                dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                locale?: string | undefined;
            } | undefined;
        } | undefined;
    } | undefined;
    templates?: {
        [x: string]: {
            messages?: PartialAll<PartialAll<Record<MK, string>>> | undefined;
            relative?: {
                default?: any;
                day?: any;
                hour?: any;
                minute?: any;
                month?: any;
                second?: any;
                year?: any;
                years?: any;
                quarter?: any;
                quarters?: any;
                months?: any;
                week?: any;
                weeks?: any;
                days?: any;
                hours?: any;
                minutes?: any;
                seconds?: any;
            } | undefined;
            plural?: {
                default?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    type?: Intl.PluralRuleType | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    locale?: string | undefined;
                } | undefined;
                cardinal?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    type?: Intl.PluralRuleType | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    locale?: string | undefined;
                } | undefined;
                ordinal?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    type?: Intl.PluralRuleType | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    locale?: string | undefined;
                } | undefined;
            } | undefined;
            number?: {
                default?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                    currency?: string | undefined;
                    currencySign?: "standard" | "accounting" | undefined;
                    useGrouping?: boolean | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    compactDisplay?: "long" | "short" | undefined;
                    notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                    signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                    unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                    unitDisplay?: "long" | "short" | "narrow" | undefined;
                    currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                    numberingSystem?: string | undefined;
                    locale?: string | undefined;
                } | undefined;
                currency?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                    currency?: string | undefined;
                    currencySign?: "standard" | "accounting" | undefined;
                    useGrouping?: boolean | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    compactDisplay?: "long" | "short" | undefined;
                    notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                    signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                    unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                    unitDisplay?: "long" | "short" | "narrow" | undefined;
                    currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                    numberingSystem?: string | undefined;
                    locale?: string | undefined;
                } | undefined;
                int?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                    currency?: string | undefined;
                    currencySign?: "standard" | "accounting" | undefined;
                    useGrouping?: boolean | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    compactDisplay?: "long" | "short" | undefined;
                    notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                    signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                    unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                    unitDisplay?: "long" | "short" | "narrow" | undefined;
                    currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                    numberingSystem?: string | undefined;
                    locale?: string | undefined;
                } | undefined;
                precent?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                    currency?: string | undefined;
                    currencySign?: "standard" | "accounting" | undefined;
                    useGrouping?: boolean | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    compactDisplay?: "long" | "short" | undefined;
                    notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                    signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                    unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                    unitDisplay?: "long" | "short" | "narrow" | undefined;
                    currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                    numberingSystem?: string | undefined;
                    locale?: string | undefined;
                } | undefined;
                k?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    style?: "percent" | "decimal" | "currency" | "unit" | undefined;
                    currency?: string | undefined;
                    currencySign?: "standard" | "accounting" | undefined;
                    useGrouping?: boolean | undefined;
                    minimumIntegerDigits?: number | undefined;
                    minimumFractionDigits?: number | undefined;
                    maximumFractionDigits?: number | undefined;
                    minimumSignificantDigits?: number | undefined;
                    maximumSignificantDigits?: number | undefined;
                    compactDisplay?: "long" | "short" | undefined;
                    notation?: "standard" | "compact" | "scientific" | "engineering" | undefined;
                    signDisplay?: "auto" | "always" | "never" | "exceptZero" | undefined;
                    unit?: "meter" | "day" | "hour" | "minute" | "month" | "second" | "year" | "percent" | "week" | "degree" | "acre" | "hectare" | "bit" | "byte" | "gigabit" | "gigabyte" | "kilobit" | "kilobyte" | "megabit" | "megabyte" | "petabyte" | "terabit" | "terabyte" | "millisecond" | "centimeter" | "foot" | "inch" | "kilometer" | "mile-scandinavian" | "mile" | "millimeter" | "yard" | "gram" | "kilogram" | "ounce" | "pound" | "stone" | "celsius" | "fahrenheit" | "fluid-ounce" | "gallon" | "liter" | "milliliter" | undefined;
                    unitDisplay?: "long" | "short" | "narrow" | undefined;
                    currencyDisplay?: "symbol" | "code" | "name" | "narrowSymbol" | undefined;
                    numberingSystem?: string | undefined;
                    locale?: string | undefined;
                } | undefined;
            } | undefined;
            date?: {
                long?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                short?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                default?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                day?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                month?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                year?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                full?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                shortYear?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                shortYearMonth?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                yearMonth?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                shortMonthDay?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                monthDay?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                shortMonth?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                shortDay?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                longDateTime?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                shortDateTime?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
            } | undefined;
            time?: {
                long?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                short?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                default?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                medium?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
                full?: {
                    localeMatcher?: "best fit" | "lookup" | undefined;
                    weekday?: "long" | "short" | "narrow" | undefined;
                    era?: "long" | "short" | "narrow" | undefined;
                    year?: "numeric" | "2-digit" | undefined;
                    month?: "long" | "short" | "narrow" | "numeric" | "2-digit" | undefined;
                    day?: "numeric" | "2-digit" | undefined;
                    hour?: "numeric" | "2-digit" | undefined;
                    minute?: "numeric" | "2-digit" | undefined;
                    second?: "numeric" | "2-digit" | undefined;
                    timeZoneName?: "long" | "short" | "shortOffset" | "longOffset" | "shortGeneric" | "longGeneric" | undefined;
                    formatMatcher?: "best fit" | "basic" | undefined;
                    hour12?: boolean | undefined;
                    timeZone?: string | undefined;
                    calendar?: string | undefined;
                    dayPeriod?: "long" | "short" | "narrow" | undefined;
                    numberingSystem?: string | undefined;
                    dateStyle?: "long" | "short" | "medium" | "full" | undefined;
                    timeStyle?: "long" | "short" | "medium" | "full" | undefined;
                    hourCycle?: "h11" | "h12" | "h23" | "h24" | undefined;
                    locale?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    } | undefined;
    formatters?: {
        formatMessage?: {} | undefined;
        formatRelativeTime?: {} | undefined;
        formatDatetime?: {} | undefined;
        formatNumber?: {} | undefined;
        formatPlural?: {} | undefined;
        formatMessageHtml?: {} | undefined;
    } | undefined;
}) => MonadI18N<MK>;
